@@ -10,7 +10,7 @@ sub apply {
     my($xml_ref) = @_;
 
     my $string = decode_utf8($$xml_ref);
-    my $match  = $string =~ s/[\x00-\x1f\x7f]//g;
+    my $match  = $string =~ s/[\x00-\x08\x0b-\x0c\x0e-\x1f\x7f]//g;
     if ($match) {
         $$xml_ref = encode_utf8($string);
         return 1;
